use std::time::{SystemTime, Duration};

use mysql::*;
use mysql::prelude::*;

fn main() -> std::result::Result<(), Box<dyn std::error::Error>> {
    //Create a connection pool
    let url = "mysql://sakila:p_ssW0rd@localhost:3306/sakila";
    let pool = Pool::new(url)?;
    let mut conn = pool.get_conn()?;

    //Outline the number of queries and mark the start time.
    const NUMQUERIES: u32 = 5_000;
    let mut times: Vec<(u32, Duration)> = vec![];
    let start_time = SystemTime::now();

    // Run the Query, NUM_QUERIES times
    for i in 0..NUMQUERIES {
        let start_query = SystemTime::now();
        let _ = conn.query_drop(r"SELECT release_year, COUNT(*) FROM sakila.film INNER JOIN (SELECT DISTINCT release_year FROM sakila.film) release_years USING (release_year) GROUP BY release_year;")?;
        times.push((i, SystemTime::now().duration_since(start_query).unwrap()))
    }

    //Output results
    println!("Total execution time: {}s", SystemTime::now().duration_since(start_time).unwrap().as_secs_f32());
    for (query_id, duration) in times.iter() {
        println!("{}: {}.{} milliseconds", query_id, duration.as_millis(), duration.as_micros());
    }

    Ok(())
}